@@ -1,4 +1,4 @@
-## Copyright 2012 Sebastian Gibb
+## Copyright 2012-2013 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquant for R and related languages.
@@ -26,16 +26,16 @@
 ## returns:
 ##
 .prepareShowGroupName <- function(x, name) {
-    if (!is.null(x)) {
-        n <- length(x);
+  if (!is.null(x)) {
+    n <- length(x)
 
-        if (n > 1) {
-            name <- paste(name, 1:n, sep="");
-        }
-
-    } else {
-        name <- NULL
+    if (n > 1) {
+      name <- paste0(name, 1:n)
     }
 
-    return(name)
+  } else {
+    name <- NULL
+  }
+
+  return(name)
 }
